HttpMarker

Trait HttpMarker 

pub trait HttpMarker { }
A HTTP plugin is a plugin that acts on the HTTP request before it is deserialized, and acts on the HTTP response after it is serialized.

This trait is a marker trait to indicate that a plugin can be registered as an HTTP plugin.

Compare with ModelMarker in the module documentation, which contains an example implementation too.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Pl> HttpMarker for &Pl
where Pl: HttpMarker,

Implementors

Source

impl HttpMarker for IdentityPlugin

Source

impl HttpMarker for InstrumentPlugin

Source

impl HttpMarker for OperationExtensionPlugin

Source

impl<Inner, F> HttpMarker for FilterByOperation<Inner, F>
where Inner: HttpMarker,

Source

impl<Inner, Outer> HttpMarker for PluginStack<Inner, Outer>
where Inner: HttpMarker, Outer: HttpMarker,

Source

impl<InnerPlugin> HttpMarker for HttpPlugins<InnerPlugin>
where InnerPlugin: HttpMarker,

Source

impl<L> HttpMarker for LayerPlugin<L>

Source

impl<Scope, Pl> HttpMarker for Scoped<Scope, Pl>
where Pl: HttpMarker,