Module aws_smithy_http_server::request::lambda
source · Available on crate feature
aws-lambda only.Expand description
The lambda_http types included in http::Requests when LambdaHandler is
used. Each are given a FromParts implementation for easy use within handlers.
Structs
ApiGatewayProxyRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function. It also includes Cognito identity information for the caller.ApiGatewayV2httpRequestContextcontains the information to identify the AWS account and resources invoking the Lambda function.- The Lambda function execution context. The values in this struct are populated using the Lambda environment variables and the headers returned by the poll request to the Runtime APIs.
- The
Contextwas not found in thehttp::Requestextensions. - The
RequestContext::ApiGatewayV1was not found in thehttp::Requestextensions. - The
RequestContext::ApiGatewayV2was not found in thehttp::Requestextensions.