Struct aws_smithy_http_server::AddExtension [−][src]
pub struct AddExtension<S, T> { /* fields omitted */ }Expand description
Middleware for adding some shareable value to request extensions.
See the module docs for more details.
Implementations
Create a new AddExtension.
Consumes self, returning the underlying service.
Returns a new Layer that wraps services with a AddExtension middleware.