Struct aws_smithy_http_server::Extension [−][src]
pub struct Extension<T>(pub T);Expand description
Extractor that gets a value from request extensions.
This is commonly used to share state across handlers.
If the extension is missing it will reject the request with a 500 Internal Server Error response.
Tuple Fields
0: TTrait Implementations
type Rejection = ExtensionRejection
type Rejection = ExtensionRejection
If the extractor fails it’ll use this “rejection” type. A rejection is a kind of error that can be converted into a response. Read more
fn from_request<'life0, 'async_trait>(
req: &'life0 mut RequestParts<B>
) -> Pin<Box<dyn Future<Output = Result<Self, Self::Rejection>> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
fn from_request<'life0, 'async_trait>(
req: &'life0 mut RequestParts<B>
) -> Pin<Box<dyn Future<Output = Result<Self, Self::Rejection>> + Send + 'async_trait>> where
'life0: 'async_trait,
Self: 'async_trait,
Perform the extraction.