Struct aws_smithy_http_server::Router [−][src]
pub struct Router<B = Body> { /* fields omitted */ }Expand description
The router is a tower::Service that routes incoming requests to other Services
based on the request’s URI and HTTP method, adhering to the Smithy specification.
It currently does not support Smithy’s endpoint trait.
You should not instantiate this router directly; it will be created for you from the
code generated from your Smithy model by smithy-rs.
Implementations
Convert this router into a MakeService, that is a Service whose
response is another service.
This is useful when running your application with hyper’s
Server.
pub fn layer<L, NewReqBody, NewResBody>(self, layer: L) -> Router<NewReqBody> where
L: Layer<Route<B>>,
L::Service: Service<Request<NewReqBody>, Response = Response<NewResBody>, Error = Infallible> + Clone + Send + 'static,
<L::Service as Service<Request<NewReqBody>>>::Future: Send + 'static,
NewResBody: HttpBody<Data = Bytes> + Send + 'static,
NewResBody::Error: Into<BoxError>,
pub fn layer<L, NewReqBody, NewResBody>(self, layer: L) -> Router<NewReqBody> where
L: Layer<Route<B>>,
L::Service: Service<Request<NewReqBody>, Response = Response<NewResBody>, Error = Infallible> + Clone + Send + 'static,
<L::Service as Service<Request<NewReqBody>>>::Future: Send + 'static,
NewResBody: HttpBody<Data = Bytes> + Send + 'static,
NewResBody::Error: Into<BoxError>,
Apply a tower::Layer to the router.
All requests to the router will be processed by the layer’s corresponding middleware.
This can be used to add additional processing to all routes.