Type Definition aws_smithy_http_server::BoxBody [−][src]
pub type BoxBody = UnsyncBoxBody<Bytes, Error>;Expand description
A boxed Body trait object.
This is used as the response body type for applications. Its necessary to unify multiple response bodies types into one.