pub trait HttpMarker { }Expand description
A HTTP plugin is a plugin that acts on the HTTP request before it is deserialized, and acts on the HTTP response after it is serialized.
This trait is a marker trait to indicate that a plugin can be registered as an HTTP plugin.
Compare with ModelMarker in the module documentation, which contains an
example implementation too.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".