Struct aws_smithy_http_server::Router [−][src]
pub struct Router<B = Body> { /* fields omitted */ }Expand description
The router type for composing handlers and services.
Implementations
pub fn layer<L, NewReqBody, NewResBody>(self, layer: L) -> Router<NewReqBody> where
L: Layer<Route<B>>,
L::Service: Service<Request<NewReqBody>, Response = Response<NewResBody>, Error = Infallible> + Clone + Send + 'static,
<L::Service as Service<Request<NewReqBody>>>::Future: Send + 'static,
NewResBody: HttpBody<Data = Bytes> + Send + 'static,
NewResBody::Error: Into<BoxError>,
pub fn layer<L, NewReqBody, NewResBody>(self, layer: L) -> Router<NewReqBody> where
L: Layer<Route<B>>,
L::Service: Service<Request<NewReqBody>, Response = Response<NewResBody>, Error = Infallible> + Clone + Send + 'static,
<L::Service as Service<Request<NewReqBody>>>::Future: Send + 'static,
NewResBody: HttpBody<Data = Bytes> + Send + 'static,
NewResBody::Error: Into<BoxError>,
Apply a tower::Layer to the router.
All requests to the router will be processed by the layer’s corresponding middleware.
This can be used to add additional processing to a request for a group of routes.